# Titre : Démo afficheur à SSD1306
# Matériels : ESP32 Feather Huzzah, Gravity OLED-2864
# IDE : Thonny
# Ressources
# https://docs.micropython.org/en/latest/esp32/quickref.html#
# https://raw.githubusercontent.com/micropython/micropython/master/drivers/display/ssd1306.py
# https://docs.micropython.org/en/latest/library/framebuf.html?highlight=framebuffer

from machine import Pin, SoftI2C
import ssd1306
import time
import urandom

# Configuration du bus i2c sur l'ESP32 Feather Huzzah
i2c = SoftI2C(scl=Pin(22), sda=Pin(23),freq=100000)
 
# Dimension de l'afficheur oled (ssd1306)
oled_width = 128 # px
oled_height = 64 # px
 
# Construction de l'objet oled
oled = ssd1306.SSD1306_I2C(oled_width, oled_height, i2c)

# Démo 1 : affichage d'un texte
# Division de l'afficheur en 8 lignes et 9 colonnes
lin_hight = 9
col_width = 8
def text_write(text, lin, col):
    oled.text(text,col*col_width,lin*lin_hight)
 
oled.fill(0) # Extinction de l'afficheur
text_write("MicroPython",1,2);
text_write("sur",3,6)
text_write("ESP32",5,5)
oled.show()
 
time.sleep(1)

# Démo 2 : affichage de ligne
# ligne horizontale : hline(pos_x1,pos_y1,pos_x2,pos_y2,c)
# ligne verticale : vline(pos_x1,pos_y1,pos_x2,pos_y2,c)
# c=0=>noir, c=1=>blanc
 
oled.hline(0,0,oled_width-1,1) 
oled.hline(0,oled_height-1,oled_width-1,1)
oled.vline(0,0,oled_height,1)
oled.vline(oled_width-1,0,oled_height,1)
oled.show()
 
time.sleep(3)

# Démo 3 : : affichage aléatoire de pixels
oled.fill(0) # Ecran noir
 
for n in range(50):
    pos_x = urandom.randint(1,oled_width)
    pos_y = urandom.randint(1,oled_height)
    oled.pixel(pos_x,pos_y,1)
oled.show()
 
time.sleep(3)

# Démo 4a
ICON = [
    [0,0,0,0,1,1,1,0,0,0,0],
    [0,0,0,1,0,0,0,1,0,0,0],
    [0,0,1,0,0,0,0,0,1,0,0],
    [0,1,0,0,0,0,0,0,0,1,0],
    [1,0,0,0,0,0,0,0,0,0,1],
    [1,1,1,1,1,1,1,1,1,1,1],
    [0,0,0,0,1,1,1,0,0,0,0],
    [0,0,0,1,0,1,0,1,0,0,0],
    [0,0,1,0,0,1,0,0,1,0,0],
    [0,1,0,0,0,1,0,0,0,1,0],
    [0,0,0,0,1,1,1,0,0,0,0],
]

# Démo 4a : affichage d'une icône au centre
oled.fill(0) # Extinction de l'afficheur
for y in range (11):
    for x in range (11):
        oled.pixel(x+64,y+32,ICON[y][x])
oled.show()
 
time.sleep(2)
 
# Démo 4b : affichage d'icônes au hazard
for n in range(12):
    pos_x = urandom.randint(1,oled_width-12)
    pos_y = urandom.randint(1,oled_height-12)
    for y, ligne in enumerate(ICON):
        for x, c in enumerate(ligne):
            oled.pixel(x+pos_x,y+pos_y,c)
oled.show()
 
time.sleep(3)

oled.fill(0) # Extinction de l'afficheur
text_write("Fin",3,6);
oled.show()